@@ -1,7 +1,7 @@
 from pathlib import Path
 import subprocess
 
-from instant_python.config.domain.dependency_configuration import DependencyConfiguration
+from instant_python.config.domain.dependency_config import DependencyConfig
 from instant_python.dependency_manager.dependency_manager import DependencyManager
 from instant_python.dependency_manager.command_execution_error import CommandExecutionError
 
@@ -11,14 +11,23 @@ class PdmDependencyManager(DependencyManager):
         super().__init__(project_directory)
         self._pdm = self._set_pdm_executable_based_on_os()
 
-    def setup_environment(self, python_version: str, dependencies: list[DependencyConfiguration]) -> None:
+    def setup_environment(self, python_version: str, dependencies: list[DependencyConfig]) -> None:
         try:
-            self._install()
+            if self._pdm_is_not_installed():
+                self._install()
             self._install_python(python_version)
             self._install_dependencies(dependencies)
         except subprocess.CalledProcessError as error:
             raise CommandExecutionError(exit_code=error.returncode, stderr_output=error.stderr)
 
+    def _pdm_is_not_installed(self) -> bool:
+        try:
+            self._run_command(f"{self._pdm} --version")
+            print(">>> pdm is already installed, skipping installation")
+            return False
+        except subprocess.CalledProcessError:
+            return True
+
     def _install(self) -> None:
         print(">>> Installing pdm...")
         self._run_command(command=self._get_installation_command_based_on_os())
@@ -41,7 +50,7 @@ class PdmDependencyManager(DependencyManager):
         self._run_command(command=f"{self._pdm} python install {version}")
         print(f">>> Python {version} installed successfully")
 
-    def _install_dependencies(self, dependencies: list[DependencyConfiguration]) -> None:
+    def _install_dependencies(self, dependencies: list[DependencyConfig]) -> None:
         self._create_virtual_environment()
         print(">>> Installing dependencies...")
         for dependency in dependencies:
@@ -49,7 +58,7 @@ class PdmDependencyManager(DependencyManager):
             self._run_command(command)
         print(">>> Dependencies installed successfully")
 
-    def _build_dependency_install_command(self, dependency: DependencyConfiguration) -> str:
+    def _build_dependency_install_command(self, dependency: DependencyConfig) -> str:
         command = [f"{self._pdm} add"]
         command.extend(dependency.get_installation_flag())
         command.append(dependency.get_specification())
