@@ -7,4 +7,4 @@ from {{ general.source_name }}.errors.domain_error import DomainError
 
 class DomainEventTypeNotFoundError(DomainError):
 	def __init__(self, name: str) -> None:
-		super().__init__(message=f"Event type {name} not found among subscriber.", error_type="domain_event_type_not_found",)
+		super().__init__(message=f"Event type {name} not found among subscriber.")
