@@ -2,7 +2,7 @@ import os
 
 from expects import expect, raise_error
 
-from instant_python.config.domain.dependency_configuration import DependencyConfiguration
+from instant_python.config.domain.dependency_config import DependencyConfig
 from instant_python.dependency_manager.command_execution_error import CommandExecutionError
 from test.dependency_manager.mock_pdm_dependency_manager import (
     MockPdmDependencyManagerWithError,
@@ -32,13 +32,13 @@ class TestPdmDependencyManager:
 
     def test_should_install_dependencies(self) -> None:
         dependencies = [
-            DependencyConfiguration(
+            DependencyConfig(
                 name="pytest",
                 version="latest",
                 is_dev=True,
                 group="test",
             ),
-            DependencyConfiguration(
+            DependencyConfig(
                 name="requests",
                 version="2.32.0",
             ),
