@@ -4,20 +4,20 @@ from expects import expect, be_none
 
 from instant_python.config.domain.config_parser import ConfigParser
 from instant_python.initialize.application.config_reader import ConfigReader
-from instant_python.initialize.domain.configuration_repository import ConfigurationRepository
-from test.config.domain.mothers.configuration_schema_mother import ConfigurationSchemaMother
+from instant_python.initialize.domain.config_repository import ConfigRepository
+from test.config.domain.mothers.config_schema_mother import ConfigSchemaMother
 
 
 class TestConfigReader:
     def test_should_read_existing_configuration_from_file(self) -> None:
-        configuration_repository = Mock(ConfigurationRepository)
+        configuration_repository = Mock(ConfigRepository)
         configuration_parser = Mock(ConfigParser)
         config_reader = ConfigReader(
             repository=configuration_repository,
             parser=configuration_parser,
         )
         config_file_path = "path/to/config/file.yml"
-        config = ConfigurationSchemaMother.any()
+        config = ConfigSchemaMother.any()
 
         expect_call(configuration_repository).read(config_file_path).returns(config.to_primitives())
         expect_call(configuration_parser).parse(config.to_primitives(), config_file_path).returns(config)
